@@ -197,12 +197,12 @@ if ($curcontent->GetPropertyValue($description_block) != '') {
 
 ///// XML LANGUAGE /////
 $monkey = $this->GetPreference('html_title','en');
+$lang_count = '0';
 if (preg_match('/{/', $monkey)) {
     $this->smarty->assign('html_title', $lang_block);
     $lang_block = str_replace('{$','',$lang_block);
     $lang_block = str_replace('}','',$lang_block);
-} else {
-    $this->smarty->assign('html_title', $this->GetPreference('html_title','en'));
+    $lang_count = '1';
 }
 
 
@@ -227,6 +227,15 @@ if ($this->GetPreference('allow_add',1) == 1) {
    $this->smarty->assign('standard_title', $this->GetPreference('standard_title','1'));
    $this->smarty->assign('dublin_title', $this->GetPreference('dublin_title','0'));
    $this->smarty->assign('opengraph_title', $this->GetPreference('opengraph_title','0'));
+   $this->smarty->assign('fullscreen_title', $this->GetPreference('fullscreen_title','-1'));
+   $this->smarty->assign('statusbar_title', $this->GetPreference('statusbar_title','-1'));
+   $this->smarty->assign('phoneno_title', $this->GetPreference('phoneno_title','-1'));
+   $this->smarty->assign('width_title', $this->GetPreference('width_title',''));
+   $this->smarty->assign('height_title', $this->GetPreference('height_title',''));
+   $this->smarty->assign('initial_title', $this->GetPreference('initial_title',''));
+   $this->smarty->assign('minimum_title', $this->GetPreference('minimum_title',''));
+   $this->smarty->assign('maximum_title', $this->GetPreference('maximum_title',''));
+   $this->smarty->assign('scalable_title', $this->GetPreference('scalable_title','-1'));
    $this->smarty->assign('publisher_title', $this->GetPreference('publisher_title',''));
    $this->smarty->assign('contributor_title', $this->GetPreference('contributor_title',''));
    $this->smarty->assign('relation_title', $this->GetPreference('relation_title',''));
@@ -252,7 +261,11 @@ if ($this->GetPreference('allow_add',1) == 1) {
    $this->smarty->assign('dir_title', $this->GetPreference('dir_title','0'));
    $this->smarty->assign('dirchoice_title', $this->GetPreference('dirchoice_title','-1'));
    $this->smarty->assign('lang_title', $this->GetPreference('lang_title','0'));
-   $this->smarty->assign('html_title', $smarty->get_template_vars($lang_block));
+   if ($lang_count != '0') {
+       $this->smarty->assign('html_title', $smarty->get_template_vars($lang_block));
+   }else{
+       $this->smarty->assign('html_title', $this->GetPreference('html_title','en'));
+   }
    $this->smarty->assign('xmllang_title', $this->GetPreference('xmllang_title','0'));
    $this->smarty->assign('htmlextra_title', $this->GetPreference('htmlextra_title',''));
    $this->smarty->assign('openhtml_title', $this->GetPreference('openhtml_title','0'));
