@@ -21,6 +21,18 @@ while ($file = readdir($dp)) {
 }
 closedir($dp);
 
+$dropDown = array();
+$dropDown[$this->Lang('drop_select')] = '-1';
+$dropDown[$this->Lang('drop_yes')] = 'yes';
+$dropDown[$this->Lang('drop_no')] = 'no';
+
+$barStyle = array();
+$barStyle[$this->Lang('style_select')] = '-1';
+$barStyle[$this->Lang('style_default')] = 'default';
+$barStyle[$this->Lang('style_black')] = 'black';
+$barStyle[$this->Lang('style_translucent')] = 'black-translucent';
+
+
 // CreateFormStart sets up a proper form tag that will cause the submit to
 // return control to this module for processing.
 $smarty->assign('startform', $this->CreateFormStart ($id, 'updatemeta', $returnid));
@@ -28,6 +40,7 @@ $smarty->assign('endform', $this->CreateFormEnd ());
 $smarty->assign('submit', $this->CreateInputSubmit ($id, 'metasubmitbutton', $this->Lang('submit')));
 $smarty->assign('legend_page_title',$this->Lang('page_title_legend'));
 $smarty->assign('legend_meta_title',$this->Lang('meta_title_legend'));
+$smarty->assign('legend_apple_title',$this->Lang('apple_title_legend'));
 $smarty->assign('legend_metaoptions_title',$this->Lang('metaoptions_title_legend'));
 $smarty->assign('page_title_help',$this->Lang('page_title_help'));
 $smarty->assign('page_smarty_help',$this->Lang('page_smarty_help'));
@@ -73,6 +86,33 @@ $smarty->assign('input_dublin_title', $this->CreateInputCheckbox($id,'dublin_tit
 $smarty->assign('title_opengraph_title',$this->Lang('opengraph_title'));
 $smarty->assign('input_opengraph_title', $this->CreateInputCheckbox($id,'opengraph_title','1', $this->GetPreference('opengraph_title','0')));
 
+$smarty->assign('title_fullscreen_title',$this->Lang('fullscreen_title'));
+$smarty->assign('input_fullscreen_title',$this->CreateInputDropdown($id,'fullscreen_title',$dropDown,$this->GetPreference('fullscreen_title','-1'),$this->GetPreference('fullscreen_title','-1')));
+
+$smarty->assign('title_statusbar_title',$this->Lang('statusbar_title'));
+$smarty->assign('input_statusbar_title',$this->CreateInputDropdown($id,'statusbar_title',$barStyle,$this->GetPreference('statusbar_title','-1'),$this->GetPreference('statusbar_title','-1')));
+
+$smarty->assign('title_phoneno_title',$this->Lang('phoneno_title'));
+$smarty->assign('input_phoneno_title',$this->CreateInputDropdown($id,'phoneno_title',$dropDown,$this->GetPreference('phoneno_title','-1'),$this->GetPreference('phoneno_title','-1')));
+
+$smarty->assign('title_width_title',$this->Lang('width_title'));
+$smarty->assign('input_width_title',$this->CreateInputText($id,'width_title',$this->GetPreference('width_title',''),10,255));
+
+$smarty->assign('title_height_title',$this->Lang('height_title'));
+$smarty->assign('input_height_title',$this->CreateInputText($id,'height_title',$this->GetPreference('height_title',''),10,255));
+
+$smarty->assign('title_initial_title',$this->Lang('initial_title'));
+$smarty->assign('input_initial_title',$this->CreateInputText($id,'initial_title',$this->GetPreference('initial_title',''),10,255));
+
+$smarty->assign('title_minimum_title',$this->Lang('minimum_title'));
+$smarty->assign('input_minimum_title',$this->CreateInputText($id,'minimum_title',$this->GetPreference('minimum_title',''),10,255));
+
+$smarty->assign('title_maximum_title',$this->Lang('maximum_title'));
+$smarty->assign('input_maximum_title',$this->CreateInputText($id,'maximum_title',$this->GetPreference('maximum_title',''),10,255));
+
+$smarty->assign('title_scalable_title',$this->Lang('scalable_title'));
+$smarty->assign('input_scalable_title',$this->CreateInputDropdown($id,'scalable_title',$dropDown,$this->GetPreference('scalable_title','-1'),$this->GetPreference('scalable_title','-1')));
+
 $smarty->assign('title_publisher_title',$this->Lang('publisher_title'));
 $smarty->assign('input_publisher_title',$this->CreateInputText($id,'publisher_title',$this->GetPreference('publisher_title',''),50,255));
 
