@@ -20,6 +20,7 @@ $lang['css_title_legend'] = 'Stylesheet options';
 $lang['jquery_title_legend'] = 'Jquery options';
 $lang['additional_title_legend'] = 'Additional content';
 $lang['meta_title_legend'] = 'Meta tags';
+$lang['apple_title_legend'] = 'Apple Meta tags';
 $lang['metaoptions_title_legend'] = 'Meta content';
 $lang['keywords_title_legend'] = 'Keyword settings';
 $lang['analytics_title_legend'] = 'Google Analytics settings';
@@ -108,6 +109,22 @@ $lang['jquery_true'] = 'True';
 $lang['jquery_false'] = 'False';
 $lang['dublin_title'] = 'Generate Dublin Core Meta Tags';
 $lang['opengraph_title'] = 'Generate OpenGraph Meta Tags (e.g. for Facebook Like Button)';
+$lang['drop_select'] = 'Please Select';
+$lang['drop_yes'] = 'Yes';
+$lang['drop_no'] = 'No';
+$lang['style_select'] = 'Please Select';
+$lang['style_default'] = 'default';
+$lang['style_black'] = 'black';
+$lang['style_translucent'] = 'black-translucent';
+$lang['fullscreen_title'] = 'Full-screen mode';
+$lang['statusbar_title'] = 'Status bar style';
+$lang['phoneno_title'] = 'Phone number detection';
+$lang['width_title'] = 'Viewport width, range is from 200 to 10,000 or device-width';
+$lang['height_title'] = 'Viewport height, range is from 223 to 10,000 or device-height';
+$lang['initial_title'] = 'Viewport initial scale';
+$lang['minimum_title'] = 'Viewport minimum scale, range is from >0 to 10.0';
+$lang['maximum_title'] = 'Viewport maximum scale, range is from >0 to 10.0';
+$lang['scalable_title'] = 'Viewport user scalable';
 $lang['publisher_title'] = 'Site publisher';
 $lang['contributor_title'] = 'Site contributor';
 $lang['relation_title'] = 'Related website';
@@ -171,7 +188,9 @@ $lang['changelog'] = '<ul>
 <li>Version 1.7.3 27 February 2012. Added seperate cms_stylesheet and cms_jquery tabs.</li>
 <li>Version 1.7.3.1 27 February 2012. Minor bug fix.</li>
 <li>Version 1.7.4 27 February 2012. Minor bug fixes and removed non working stylesheet and jquery params to avoid confusion.</li>
-<li>Version 1.7.4.1 29 February 2012. Minor bug fix and the addition of smarty use in the language field, useful for mulitlingual sites.</li></ul>';
+<li>Version 1.7.4.1 29 February 2012. Minor bug fix and the addition of smarty use in the language field, useful for mulitlingual sites.</li>
+<li>Version 1.7.4.2 29 February 2012. Added the ability to display Apple meta tags.</li>
+<li>Version 1.7.4.3 1 March 2012. Minor bug fix.</li></ul>';
 $lang['help'] = '<h3>What Does This Do?</h3>
 <p>This module adds the ability to include additional Meta data, Analytics tracking code and other useful SEO information. It can also be used to generate Doctype and Head tags, replacing the entire head of your document.</p>
 <h3>How Do I Use It</h3>
@@ -182,6 +201,7 @@ $lang['help'] = '<h3>What Does This Do?</h3>
 <p>If you are using the auto description option you will need to add &#123;capture}&#123;content block=\'Page Description\' oneline=\'true\' wysiwyg=\'false\'}&#123;/capture} to your templates and reference this content blocks name in the \'page description content block\' input field, which in this example is Page Description.</p>
 <p>If you want page specific metadata simply add &#123;capture}&#123;content block=\'Metadata\' wysiwyg=\'false\'}&#123;/capture} to your templates and reference this content blocks namie in the \'metadata content block\' input field, which in this example is Metadata.</p>
 <p>The Analytics search options are only required if you are using pretty URL\'s in conjunction with the search module\'s POST method otherwise simply adding the default cntnt01searchinput into your Analytics setup will track site search queries.</p>
+<p>There are more examples and instructions available at https://sites.google.com/site/metamaxwiki/ please feel free to contribute any examples and findings you have.</p>
 <h3>Support</h3>
 <p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
 <ul>
